@@ -46,8 +46,8 @@ from __future__ import unicode_literals
 
 import sys
 
-VERSION_INFO = (1, 3, 1)
-DATE_INFO = (2014, 10, 16)  # YEAR, MONTH, DAY
+VERSION_INFO = (1, 3, 2)
+DATE_INFO = (2014, 10, 17)  # YEAR, MONTH, DAY
 VERSION = '.'.join(str(i) for i in VERSION_INFO)
 REVISION = '%04d%02d%02d' % DATE_INFO
 BUILD_INFO = "pyScss v" + VERSION + " (" + REVISION + ")"
@@ -57,13 +57,3 @@ URL = 'http://github.com/Kronuz/pyScss'
 DOWNLOAD_URL = 'http://github.com/Kronuz/pyScss/tarball/v' + VERSION
 LICENSE = "MIT"
 PROJECT = "pyScss"
-
-if __name__ == "__main__":
-    print('VERSION      = ' + VERSION)
-    print('REVISION     = ' + REVISION)
-    print('BUILD_INFO   = ' + BUILD_INFO)
-    print('AUTHOR       = ' + AUTHOR)
-    print('AUTHOR_EMAIL = ' + AUTHOR_EMAIL)
-    print('URL          = ' + URL)
-    print('LICENSE      = ' + LICENSE)
-    print('PROJECT      = ' + PROJECT)
